@@ -58,6 +58,16 @@ from pymongo.errors import (AutoReconnect,
 _CONNECT_TIMEOUT = 20.0
 
 
+def _partition_ipv6(source):
+    if source.find(']') == -1:
+        raise InvalidURI("an IPv6 address literal must be "
+                         "enclosed in '[' and ']' characters.")
+    i = source.find(']:')
+    if i == -1:
+        return (source[1:-1], None)
+    return (source[1: i], source[i + 2:])
+
+
 def _partition(source, sub):
     """Our own string partitioning method.
 
@@ -74,7 +84,14 @@ def _str_to_node(string, default_port=27017):
 
     "localhost:27017" -> ("localhost", 27017)
     """
-    (host, port) = _partition(string, ":")
+    # IPv6 literal
+    if string[0] == '[':
+        host, port = _partition_ipv6(string)
+    elif string.count(':') > 1 or string.find(']') != -1:
+        raise InvalidURI("an IPv6 address literal must be "
+                         "enclosed in '[' and ']' characters.")
+    else:
+        host, port = _partition(string, ":")
     if port:
         port = int(port)
     else:
@@ -123,6 +140,7 @@ def _parse_uri(uri, default_port=27017):
 
     options = {}
     if raw_options:
+        raw_options = raw_options.lower()
         and_idx = raw_options.find("&")
         semi_idx = raw_options.find(";")
         if and_idx >= 0 and semi_idx >= 0:
@@ -151,9 +169,7 @@ class _Pool(threading.local):
     """A simple connection pool.
 
     Uses thread-local socket per thread. By calling return_socket() a
-    thread can return a socket to the pool. Right now the pool size is
-    capped at 10 sockets - we can expose this as a parameter later, if
-    needed.
+    thread can return a socket to the pool.
     """
 
     # Non thread-locals
@@ -162,9 +178,9 @@ class _Pool(threading.local):
     # thread-local default
     sock = None
 
-    def __init__(self, socket_factory):
+    def __init__(self, socket_factory, pool_size):
         self.pid = os.getpid()
-        self.pool_size = 10
+        self.pool_size = pool_size
         self.socket_factory = socket_factory
         if not hasattr(self, "sockets"):
             self.sockets = []
@@ -211,10 +227,9 @@ class Connection(object):  # TODO support auth for pooling
 
     __max_bson_size = 4 * 1024 * 1024
 
-    def __init__(self, host=None, port=None, pool_size=None,
-                 auto_start_request=None, timeout=None, slave_okay=False,
-                 network_timeout=None, document_class=dict, tz_aware=False,
-                 _connect=True):
+    def __init__(self, host=None, port=None, max_pool_size=10,
+                 slave_okay=False, network_timeout=None,
+                 document_class=dict, tz_aware=False, _connect=True):
         """Create a new connection to a single MongoDB instance at *host:port*.
 
         The resultant connection object has connection-pooling built
@@ -240,15 +255,16 @@ class Connection(object):  # TODO support auth for pooling
         username, and password present will be used.
 
         :Parameters:
-          - `host` (optional): hostname or IPv4 address of the
+          - `host` (optional): hostname or IP address of the
             instance to connect to, or a mongodb URI, or a list of
-            hostnames / mongodb URIs
+            hostnames / mongodb URIs. If `host` is an IPv6 literal
+            it must be enclosed in '[' and ']' characters following
+            the RFC2732 URL syntax (e.g. '[::1]' for localhost)
           - `port` (optional): port number on which to connect
-          - `pool_size` (optional): DEPRECATED
-          - `auto_start_request` (optional): DEPRECATED
+          - `max_pool_size` (optional): The maximum size limit for
+            the connection pool.
           - `slave_okay` (optional): is it okay to connect directly to
             and perform queries on a slave instance
-          - `timeout` (optional): DEPRECATED
           - `network_timeout` (optional): timeout (in seconds) to use
             for socket operations - default is no timeout
           - `document_class` (optional): default class to use for
@@ -259,6 +275,9 @@ class Connection(object):  # TODO support auth for pooling
             aware (otherwise they will be naive)
 
         .. seealso:: :meth:`end_request`
+        .. versionchanged:: 1.10.1+
+           Added `max_pool_size`. Completely removed previously deprecated
+           `pool_size`, `auto_start_request` and `timeout` parameters.
         .. versionchanged:: 1.8
            The `host` parameter can now be a full `mongodb URI
            <http://dochub.mongodb.org/core/connections>`_, in addition
@@ -306,24 +325,23 @@ class Connection(object):  # TODO support auth for pooling
             raise InvalidURI("cannot specify database without "
                              "a username and password")
 
-        if pool_size is not None:
-            warnings.warn("The pool_size parameter to Connection is "
-                          "deprecated", DeprecationWarning)
-        if auto_start_request is not None:
-            warnings.warn("The auto_start_request parameter to Connection "
-                          "is deprecated", DeprecationWarning)
-        if timeout is not None:
-            warnings.warn("The timeout parameter to Connection is deprecated",
-                          DeprecationWarning)
-
         self.__host = None
         self.__port = None
 
-        for k in options.iterkeys():
-            # PYTHON-205 - Lets not break existing client code.
-            if k in ("slaveOk", "slaveok"):
-                self.__slave_okay = (options[k][0].upper() == 'T')
-                break
+        if "maxpoolsize" in options:
+            self.__max_pool_size = options['maxpoolsize']
+            if not self.__max_pool_size.isdigit():
+                raise TypeError("maxPoolSize must be an integer >= 0.")
+            self.__max_pool_size = int(self.__max_pool_size)
+        else:
+            self.__max_pool_size = max_pool_size
+            if not isinstance(self.__max_pool_size, int):
+                raise TypeError("max_pool_size must be an instance of int.")
+        if self.__max_pool_size < 0:
+            raise ValueError("the maximum pool size must be >= 0")
+
+        if "slaveok" in options:
+            self.__slave_okay = (options['slaveok'][0].upper() == 'T')
         else:
             self.__slave_okay = slave_okay
 
@@ -338,7 +356,7 @@ class Connection(object):  # TODO support auth for pooling
 
         self.__cursor_manager = CursorManager(self)
 
-        self.__pool = _Pool(self.__connect)
+        self.__pool = _Pool(self.__connect, self.__max_pool_size)
         self.__last_checkout = time.time()
 
         self.__network_timeout = network_timeout
@@ -456,6 +474,14 @@ class Connection(object):  # TODO support auth for pooling
         """
         return self.__port
 
+    @property
+    def max_pool_size(self):
+        """The maximum pool size limit set for this connection.
+
+        .. versionadded:: 1.10.1+
+        """
+        return self.__max_pool_size
+
     @property
     def nodes(self):
         """List of all known nodes.
@@ -573,6 +599,9 @@ class Connection(object):  # TODO support auth for pooling
             if self.__try_node(node) is True:
                 return node
 
+        # Clear the connection pool so we we don't try
+        # running queries against a secondary without slave_okay.
+        self.disconnect()
         raise AutoReconnect("could not find master/primary")
 
     def __connect(self):
@@ -585,12 +614,23 @@ class Connection(object):  # TODO support auth for pooling
             host, port = self.__find_master()
 
         try:
-            sock = socket.socket()
-            sock.setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, 1)
-            sock.settimeout(self.__network_timeout or _CONNECT_TIMEOUT)
-            sock.connect((host, port))
-            sock.settimeout(self.__network_timeout)
-            return sock
+            try:
+                # Prefer IPv4. If there is demand for an option
+                # to specify one or the other we can add it later.
+                sock = socket.socket(socket.AF_INET)
+                sock.setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, 1)
+                sock.settimeout(self.__network_timeout or _CONNECT_TIMEOUT)
+                sock.connect((host, port))
+                sock.settimeout(self.__network_timeout)
+                return sock
+            except socket.gaierror:
+                # If that fails try IPv6
+                sock = socket.socket(socket.AF_INET6)
+                sock.setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, 1)
+                sock.settimeout(self.__network_timeout or _CONNECT_TIMEOUT)
+                sock.connect((host, port))
+                sock.settimeout(self.__network_timeout)
+                return sock
         except socket.error:
             self.disconnect()
             raise AutoReconnect("could not connect to %r" % list(self.__nodes))
@@ -628,7 +668,7 @@ class Connection(object):  # TODO support auth for pooling
         .. seealso:: :meth:`end_request`
         .. versionadded:: 1.3
         """
-        self.__pool = _Pool(self.__connect)
+        self.__pool = _Pool(self.__connect, self.__max_pool_size)
         self.__host = None
         self.__port = None
 
