@@ -24,6 +24,7 @@ from nose.plugins.skip import SkipTest
 
 from pymongo.errors import ConnectionFailure, InvalidName
 from pymongo.errors import CollectionInvalid, OperationFailure
+from pymongo.errors import AutoReconnect
 from pymongo.database import Database
 from pymongo.connection import Connection
 from pymongo.collection import Collection
@@ -67,6 +68,90 @@ class TestMasterSlaveConnection(unittest.TestCase):
                          "MasterSlaveConnection(%r, %r)" %
                          (self.master, self.slaves))
 
+    def test_disconnect(self):
+        class Connection(object):
+            def __init__(self):
+                self._disconnects = 0
+
+            def disconnect(self):
+                self._disconnects += 1
+
+        self.connection._MasterSlaveConnection__master = Connection()
+        self.connection._MasterSlaveConnection__slaves = [Connection(),
+                                                          Connection()]
+
+        self.connection.disconnect()
+        self.assertEquals(1,
+            self.connection._MasterSlaveConnection__master._disconnects)
+        self.assertEquals(1,
+            self.connection._MasterSlaveConnection__slaves[0]._disconnects)
+        self.assertEquals(1,
+            self.connection._MasterSlaveConnection__slaves[1]._disconnects)
+
+    def test_continue_until_slave_works(self):
+        class Slave(object):
+            calls = 0
+
+            def __init__(self, fail):
+                self._fail = fail
+
+            def _send_message_with_response(self, *args, **kwargs):
+                Slave.calls += 1
+                if self._fail:
+                    raise AutoReconnect()
+                return 'sent'
+
+        class NotRandomList(object):
+            last_idx = -1
+
+            def __init__(self):
+                self._items = [Slave(True), Slave(True),
+                               Slave(False), Slave(True)]
+
+            def __len__(self):
+                return len(self._items)
+
+            def __getitem__(self, idx):
+                NotRandomList.last_idx = idx
+                return self._items.pop(0)
+
+        self.connection._MasterSlaveConnection__slaves = NotRandomList()
+
+        response = self.connection._send_message_with_response('message')
+        self.assertEquals((NotRandomList.last_idx, 'sent'), response)
+        self.assertNotEquals(-1, NotRandomList.last_idx)
+        self.assertEquals(3, Slave.calls)
+
+    def test_raise_autoreconnect_if_all_slaves_fail(self):
+        class Slave(object):
+            calls = 0
+
+            def __init__(self, fail):
+                self._fail = fail
+
+            def _send_message_with_response(self, *args, **kwargs):
+                Slave.calls += 1
+                if self._fail:
+                    raise AutoReconnect()
+                return 'sent'
+
+        class NotRandomList(object):
+            def __init__(self):
+                self._items = [Slave(True), Slave(True),
+                               Slave(True), Slave(True)]
+
+            def __len__(self):
+                return len(self._items)
+
+            def __getitem__(self, idx):
+                return self._items.pop(0)
+
+        self.connection._MasterSlaveConnection__slaves = NotRandomList()
+
+        self.assertRaises(AutoReconnect,
+            self.connection._send_message_with_response, 'message')
+        self.assertEquals(4, Slave.calls)
+
     def test_get_db(self):
 
         def make_db(base, name):
@@ -146,7 +231,8 @@ class TestMasterSlaveConnection(unittest.TestCase):
         self.db.test.create_index('username', unique=True)
 
         self.db.test.save({'username': 'mike'}, safe=True)
-        self.assertRaises(OperationFailure, self.db.test.save, {'username': 'mike'}, safe=True)
+        self.assertRaises(OperationFailure,
+                          self.db.test.save, {'username': 'mike'}, safe=True)
 
     # NOTE this test is non-deterministic, but I expect
     # some failures unless the db is pulling instantaneously...
@@ -196,7 +282,7 @@ class TestMasterSlaveConnection(unittest.TestCase):
 
         for i in range(10000):
             db.test.insert({"i": i})
-        time.sleep(11) # need to sleep to be sure this gets pulled...
+        time.sleep(11)  # need to sleep to be sure this gets pulled...
 
         self.assertEqual(before, cursor_count())
 
